photo_view_gallery library
Classes
- PhotoViewGallery
-
A type definition for a Function that defines a page in
PhotoViewGallery.buildA StatefulWidget that shows multiple PhotoView widgets in a PageView
Typedefs
- PhotoViewGalleryPageChangedCallback = void Function(int index)
- A type definition for a Function that receives a index after a page change in PhotoViewGallery